@@ -37,7 +37,7 @@ CSVWriter::OutputSingleFile(FTDCParser *pParser, std::string prefix,  std::vecto
         out_file.open(prefix, std::ios::out);
 
         // Get timestamp
-        auto  ts_metric = pParser->getMetric((std::string &) "start"); /// ALL OF IT.
+        auto  ts_metric = pParser->getMetric(  "start"); /// ALL OF IT.
 
         // Write metrics header
         std::vector<std::vector< uint64_t>*> mm;
@@ -48,7 +48,7 @@ CSVWriter::OutputSingleFile(FTDCParser *pParser, std::string prefix,  std::vecto
 
             auto metric_values = pParser->getMetric(metric_name);
 
-            if (metric_values->size() > 0) {  // getMetricsCopy(metric_name)) { ;
+            if (metric_values->size() == 0) {  // getMetricsCopy(metric_name)) { ;
                 BOOST_LOG_TRIVIAL(error) << "No metric named '" << metric_name << "' was found in parsed data.";
             }
             else {
