@@ -21,7 +21,13 @@
 Chunk::Chunk (const uint8_t *data, size_t size, int64_t id=-1, bool logMetricNames=0) {
     compressed = new uint8_t[size];
     compressed_size = size;
-    this->id = id/1000;
+
+    this->id = id/1000; //TODO: Why divide?
+
+    // We know where this chunk starts, but not where it ends
+    this->start = id;
+    this->end = INVALID_TIMESTAMP;
+
     if (!memcpy(compressed, data, size)) {
         BOOST_LOG_TRIVIAL(fatal) << "Could not allocate " << size << " while parsing chunkVector.";
     }
@@ -29,6 +35,7 @@ Chunk::Chunk (const uint8_t *data, size_t size, int64_t id=-1, bool logMetricNam
 
 size_t
 Chunk::getMetricNames(std::vector<std::string> & metricNames) {
+
     for (auto &m : metrics) {
         metricNames.emplace_back(m->name);
     }
@@ -291,6 +298,7 @@ Chunk::ConstructMetrics(const uint8_t* data ) {
     deltasInChunk = *(uint32_t*)(pp + 4);
 
     // This is the number of structures needed
+    BOOST_LOG_TRIVIAL(debug) << "Metrics in chunk to reserve: " << metricsInChunk ;
     metrics.reserve(metricsInChunk);
 
     if ((b = bson_new_from_data (data, (size_t)(*dataSize)))) {
@@ -323,12 +331,34 @@ Chunk::ConstructMetrics(const uint8_t* data ) {
         bson_destroy (b);
     }
 
+    // Get actual values
+    ReadVariableSizedInts();
+    setTimestampLimits();
+
     return metrics.size();
 }
 
 void
 Chunk::setTimestampLimits() {
-    this->start = metrics[0]->values[0];
-    this->end = metrics[0]->values[this->getSamplesCount()-1];
+    start = metrics[0]->values[0];
+    end = metrics[0]->values[getSamplesCount()-1];
 }
 
+bool Chunk::miau() {
+
+    if (Decompress() > 0) {
+        auto data = getUncompressedData();
+
+        // We construct the metrics. These are name and first value only since deltasInChunk have not been read.
+        ConstructMetrics(data);
+
+        // Get actual values
+        ReadVariableSizedInts();
+        setTimestampLimits();
+        return true;
+    }
+    else
+        return false;
+}
+
+
