@@ -12,19 +12,26 @@
 
 namespace logging = boost::log;
 
+size_t
+Dataset::LoadMetricsNamesFromChunk() {
+    if (chunkVector.size() > 0) {
+        if (lazyParsing && (chunkVector[0]->getUncompressedSize() == 0)) {
+            // miau the first chunk, so we have metric names.
+            chunkVector[0]->miau();
+        }
+        chunkVector[0]->getMetricNames(metricNames);
+        return metricNames.size();
+    }
+
+    return 0;
+}
+
+
 size_t
 Dataset::getMetricNames(std::vector<std::string> & metrics) {
 
-    if (metricNames.empty()) {
-        if (chunkVector.size() > 0) {
-
-            if (lazyParsing && (chunkVector[0]->getUncompressedSize() == 0)) {
-                // miau the first chunk, so we have metric names.
-                chunkVector[0]->miau();
-            }
-            chunkVector[0]->getMetricNames(metricNames);
-        }
-    }
+    if (metricNames.empty())
+       LoadMetricsNamesFromChunk();
 
     metrics = metricNames;
     return metrics.size();
@@ -44,17 +51,6 @@ Dataset::addChunk(Chunk *pChunk) {
     mu.unlock();
 }
 
-
-void
-Dataset::addMergedMetric(std::string   metricName,  Dataset::MetricsPtr data) {
-
-    // Critical section
-    mu.lock();
-    hashMapMetrics.emplace( metricName, data);
-    // Append metrics here.
-    mu.unlock();
-}
-
 void
 Dataset::sortChunks() {
     struct {
@@ -64,13 +60,36 @@ Dataset::sortChunks() {
 }
 
 
+bool
+Dataset::IsMetricInDataset(const std::string& metric) {
+
+    // If lazy parsing,
+    if (metricNames.empty())
+        LoadMetricsNamesFromChunk();
+
+    for (const auto& m: metricNames)
+        if (m.compare((metric)) == 0)
+            return true;
+
+    return false;
+}
+
 Dataset::MetricsPtr
-Dataset::getMetric(std::string   metricName, size_t start, size_t end)
+Dataset::getMetric(std::string   metricName, const size_t start, const size_t end, bool ratedMetric)
 {
+
+    if (metricName.at(0) == '@')  {
+        metricName = metricName.substr(1,metricName.size()-1);
+        ratedMetric = true;
+    }
+
+    if (!IsMetricInDataset(metricName)) {
+        return nullptr;
+    }
+
     auto start_chunk_pos = getLocationInMetric(start, true);
     auto end_chunk_pos = getLocationInMetric(end, false);
 
-    // TODO:  in case of lazy parsing, we should be  parsing here
     if (lazyParsing) { ;
         // for chunks between start and end, start parser threads
         for (auto chunkNumber = start_chunk_pos.getChunkLoc(); chunkNumber<=end_chunk_pos.getChunkLoc(); ++chunkNumber ) {
@@ -79,36 +98,14 @@ Dataset::getMetric(std::string   metricName, size_t start, size_t end)
         }
     }
 
-    Dataset::MetricsPtr p =  assembleMetricFromChunks(metricName, start_chunk_pos, end_chunk_pos);
 
-    return p;
+    Dataset::MetricsPtr metrics =  assembleMetricFromChunks(metricName, start_chunk_pos, end_chunk_pos);
+    if (ratedMetric)
+        ConvertToRatedMetric(metrics);
+
+    return metrics;
 }
 
-void
-Dataset::FileParsed(const char * filePath,
-                    uint64_t start, uint64_t end,
-                    size_t samples) {
-
-    int metricsNameLen = 0;
-    for (auto chunk : chunkVector) {
-
-        auto currMetricLen = chunk->getMetricsCount();
-        if (metricsNameLen != 0  && metricsNameLen!=currMetricLen) {
-            BOOST_LOG_TRIVIAL(debug) << "Number of metrics differ from chunk to chunk:" << metricsNameLen << "!= " << currMetricLen;
-        }
-
-        if (metricsNameLen!=currMetricLen) {
-            metricNames.clear();
-            chunk->getMetricNames(metricNames);
-            metricsNameLen = currMetricLen;
-        }
-    }
-
-    auto fileData = new FileParsedData(filePath, start, end, samples);
-    filesParsed.emplace_back(fileData);
-}
-
-
 SampleLocation
 Dataset::getLocationInMetric(size_t sample, bool fromStart) {
 
@@ -174,7 +171,6 @@ Dataset::assembleMetricFromChunks(const std::string metricName, SampleLocation s
         p->assign(c + startSamplePos, c + endSamplePos);
     }
     else {
-
         size_t sampleCount = (endChunk-startChunk)*ChunkMetric::MAX_SAMPLES;
         BOOST_LOG_TRIVIAL(info) << "Metric: '" << metricName << "'. Reserving for " << sampleCount << " samples.";
         p->reserve(sampleCount);
@@ -191,9 +187,97 @@ Dataset::assembleMetricFromChunks(const std::string metricName, SampleLocation s
         // Append last chunk
         c = chunkVector[endChunk]->getMetric(metricName);
         p->insert(p->end(), c, c + endSamplePos);
-
-
     }
     return p;
 }
 
+bool
+Dataset::ConvertToRatedMetric(Dataset::MetricsPtr metric) {
+
+    bool goesNegative = false;
+
+    auto it = metric->end();
+
+    for (auto prev = it-1; it != metric->begin(); --it, --prev) {
+        *it -= *prev;
+        if (*it < 0) goesNegative = true;
+    }
+
+    // Remove first element because there is no way of calculating delta (this way avg, min, max are valid!).
+    //metric->erase(metric->begin());
+
+    // Or keep element, copying from 1st position.
+    metric->at(0) = metric->at(1);
+
+    return !goesNegative;
+}
+
+void
+Dataset::FileParsed(const std::string filePath, uint64_t start, uint64_t end, size_t samplesInFile) {
+    int metricsNameLen = 0;
+    for (auto chunk : chunkVector) {
+
+        auto currMetricLen = chunk->getMetricsCount();
+        if (metricsNameLen != 0  && metricsNameLen!=currMetricLen) {
+            BOOST_LOG_TRIVIAL(debug) << "Number of metrics differ from chunk to chunk:" << metricsNameLen << "!= " << currMetricLen;
+        }
+
+        if (metricsNameLen!=currMetricLen) {
+            metricNames.clear();
+            chunk->getMetricNames(metricNames);
+            metricsNameLen = currMetricLen;
+        }
+    }
+
+    auto fileData = new FileParsedData(filePath.c_str(), start, end, samplesInFile);
+    filesParsed.emplace_back(fileData);
+}
+
+std::vector<Dataset::MetricsPtr>
+Dataset::getMetrics(const std::vector<std::string> metricNames,
+                    const size_t start, const size_t end,
+                    const bool ratedMetrics) {
+
+    std::vector<Dataset::MetricsPtr> metricList;
+
+    for(auto name : metricNames) {
+        auto element = getMetric(name, start, end, ratedMetrics);
+        metricList.emplace_back(element);
+    }
+
+    return metricList;
+}
+
+Dataset::MetricsPtr
+Dataset::getMetricMatrix(const std::vector<std::string> metricNames, size_t *stride, const size_t start, const size_t end,
+                         const bool ratedMetrics) {
+
+    //  Get metrics
+    auto mm = getMetrics(metricNames, start, end, ratedMetrics);
+    // get a length
+    size_t len=0;
+    for (auto m: mm) {
+        if (m && m->size()>0) {
+            len = m->size();
+
+            if (stride)
+                *stride = len;
+            break;
+        }
+    }
+
+    // Allocate
+    Dataset::MetricsPtr p = new std::vector<uint64_t>;
+
+    p->reserve(len*metricNames.size());
+
+    for (auto m: mm) {
+        if (m)
+            p->insert(p->end(), m->begin(),m->end());
+        else
+            p->insert(p->end(), len, 0);
+    }
+
+    return p;
+
+}
