@@ -118,10 +118,10 @@ FTDCParser::parseFiles(std::vector<std::string> const *filePaths, const bool onl
     namespace logging = boost::log;
     logging::core::get()->set_filter(logging::trivial::severity >  logging::trivial::debug);
 
-    for (auto file_name : *filePaths) {
-        BOOST_LOG_TRIVIAL(info) << "File: " << file_name;
+    for (auto fileName : *filePaths) {
+        BOOST_LOG_TRIVIAL(info) << "File: " << fileName;
 
-        reader = this->open(file_name);
+        reader = this->open(fileName);
         if (!reader) return -1;
 
         date_time_before = double_time_of_day();
@@ -193,7 +193,7 @@ FTDCParser::parseFiles(std::vector<std::string> const *filePaths, const bool onl
         date_time_delta = BSON_MAX ((double) (date_time_after - date_time_before), 0.000001);
 
         // This is the end of a file being parsed.
-        dataSet.FileParsed(file_name.c_str(), first_id, current_id, chunkCount);
+        dataSet.FileParsed(fileName, first_id, current_id, chunkCount);
 
         BOOST_LOG_TRIVIAL(info) << "File parsed in " << date_time_delta
                  << " secs. There are " << dataSet.getChunkCount() << " chunks, "
@@ -208,7 +208,6 @@ FTDCParser::parseFiles(std::vector<std::string> const *filePaths, const bool onl
                                 << "  integral unshared data size: " << usage.ru_idrss
                                 << "  integral unshared stack size" << usage.ru_isrss;
 
-
         if (onlyMetricNames) {
             std::vector<std::string> names;
             dataSet.getMetricNames(names);
@@ -247,8 +246,17 @@ FTDCParser::getMetricsNames() {
 }
 
 Dataset::MetricsPtr
-FTDCParser::getMetric(std::string name, size_t start, size_t end) {
-     return dataSet.getMetric(name, start, end);
+FTDCParser::getMetric(const std::string name, const size_t start, const size_t end, const bool ratedMetric) {
+     return dataSet.getMetric(name, start, end, ratedMetric);
 }
 
+std::vector<Dataset::MetricsPtr>
+FTDCParser::getMetric(const std::vector<std::string> metricNames, const size_t start, const size_t end, const bool ratedMetric) {
+    return  dataSet.getMetrics(metricNames, start, end, ratedMetric);
+}
+
+Dataset::MetricsPtr
+FTDCParser::getMetricMatrix(const std::vector<std::string> metricNames,   size_t *stride,  const size_t start, const size_t end, const bool ratedMetric) {
+    return  dataSet.getMetricMatrix(metricNames, stride, start, end, ratedMetric);
+}
 
