@@ -23,6 +23,9 @@ class Chunk {
 public:
 
     static const int CHUNK_MAX_SIZE = 1000000;
+    static const int INVALID_CHUNK_NUMBER   = INT_MAX;
+    static const int INVALID_TIMESTAMP_POS = INT_MAX;
+    static const uint64_t INVALID_TIMESTAMP = UINT64_MAX;
 
     Chunk (const uint8_t *data, size_t size, int64_t id, bool logMetricNames);
     ~Chunk() {
@@ -34,11 +37,11 @@ public:
     size_t getUncompressedSize() const { return decompressed_size; };
     int ReadVariableSizedInts();
     int ConstructMetrics(const uint8_t *data);
-
     int getMetricsCount() { return metrics.size(); }
-    // TODO: Remove this method, as it is only used in tests and tests can be done in a better way.
+
+
     ChunkMetric *getMetric(int metricNumber) { return metrics[metricNumber]; };
-    size_t getMetric(const std::string &metricName, uint64_t *data)  {
+    size_t getMetric(const std::string metricName, uint64_t *data)  {
         for ( auto &m : metrics) {
             if (m->name == metricName) {
                 memcpy(data, m->values, (deltasInChunk+1)*sizeof(uint64_t));
@@ -47,19 +50,24 @@ public:
         }
         return 0;
     }
-
+    uint64_t *getMetric(const std::string metricName) {
+        for ( auto &m : metrics) {
+            if (m->name == metricName)
+                return m->values;
+        }
+        return 0;
+    }
     size_t getMetricNames(std::vector<std::string> & metricNames);
 
     int64_t getId() const { return id; };
     size_t getSamplesCount() const { return 1+deltasInChunk; };
     uint64_t getStart() { return  start; };
     uint64_t getEnd() { return end; };
-
     void setTimestampLimits();
 
-    bool operator<(Chunk const &other) {
-        return id < other.id;
-    }
+    bool operator<(Chunk const &other) {  return id < other.id; }
+
+    bool miau() ;
 
 private:
     int inflate(const void *src, int srcLen, void *dst, int dstLen);
@@ -80,6 +88,7 @@ private:
     int32_t metricsInChunk;
     int32_t deltasInChunk;
 
+
 };
 
 
